==> kicad_0.0.20060829.orig.tar.gz: kicad-0.0.20060828/include/bitmaps.h <==
	/****************************/
	/* Used bitmaps in Kicad */
	/****************************/

	#include "../bitmaps/Cancel.xpm"
	#include "../bitmaps/cancel_tool.xpm"
	#include "../bitmaps/Apply.xpm"

	#include "../bitmaps/Fonts.xpm"

	#include "../bitmaps/save.xpm"
	#include "../bitmaps/save_as.xpm"
	#include "../bitmaps/Save_Project.xpm"
	#include "../bitmaps/Save_CmpStuff.xpm"
	#include "../bitmaps/Save_NetList.xpm"
	#include "../bitmaps/Save_SetUp.xpm"
	#include "../bitmaps/Read_SetUp.xpm"

	#include "../bitmaps/Open_Library.xpm"
	#include "../bitmaps/New_Library.xpm"
	#include "../bitmaps/Save_Library.xpm"

	#include "../bitmaps/Edit.xpm"
	#include "../bitmaps/Edit_Text.xpm"

	#include "../bitmaps/plot.xpm"
	#include "../bitmaps/plot_PS.xpm"
	#include "../bitmaps/plot_HPG.xpm"

	#include "../bitmaps/Add_Circle.xpm"
	#include "../bitmaps/Add_Line.xpm"
	#include "../bitmaps/Add_Arc.xpm"
	#include "../bitmaps/Add_Dashed_Line.xpm"
	#include "../bitmaps/Add_Entry.xpm"
	#include "../bitmaps/Add_Polygon.xpm"
	#include "../bitmaps/Add_Rectangle.xpm"
	#include "../bitmaps/Add_Text.xpm"
	#include "../bitmaps/Add_Line_Label.xpm"
	#include "../bitmaps/Add_GLabel.xpm"
	#include "../bitmaps/Add_Junction.xpm"

	#include "../bitmaps/general_deletions.xpm"
	#include "../bitmaps/Delete_Text.xpm"
	#include "../bitmaps/Delete_Cotation.xpm"
	#include "../bitmaps/Delete_Arc.xpm"
	#include "../bitmaps/Delete_Circle.xpm"
	#include "../bitmaps/Delete_Field.xpm"
	#include "../bitmaps/Delete_Line.xpm"
	#include "../bitmaps/Delete_Segment.xpm"
	#include "../bitmaps/Delete_Polygon.xpm"
	#include "../bitmaps/Delete_Rectangle.xpm"

	#include "../bitmaps/Move.xpm"
	#include "../bitmaps/Move_Text.xpm"
	#include "../bitmaps/Move_Arc.xpm"
	#include "../bitmaps/Move_Circle.xpm"
	#include "../bitmaps/Move_Field.xpm"
	#include "../bitmaps/Move_Line.xpm"
	#include "../bitmaps/Move_Polygon.xpm"
	#include "../bitmaps/Move_Rectangle.xpm"

	#include "../bitmaps/Options_Text.xpm"
	#include "../bitmaps/Options_Arc.xpm"
	#include "../bitmaps/Options_Circle.xpm"
	#include "../bitmaps/Options_Segment.xpm"
	#include "../bitmaps/Options_Rectangle.xpm"
	#include "../bitmaps/Display_Options.xpm"

	#include "../bitmaps/Mirror_V.xpm"
	#include "../bitmaps/Mirror_H.xpm"
	#include "../bitmaps/Orient.xpm"
	#include "../bitmaps/Rotate+.xpm"
	#include "../bitmaps/Rotate-.xpm"
	#include "../bitmaps/Rotate_Field.xpm"
	#include "../bitmaps/Exit.xpm"
	#include "../bitmaps/Datasheet.xpm"
	#include "../bitmaps/CopyBlock.xpm"
	#include "../bitmaps/new.xpm"
	#include "../bitmaps/open.xpm"
	#include "../bitmaps/polar.xpm"
	#include "../bitmaps/copy.xpm"
	#include "../bitmaps/cut.xpm"
	#include "../bitmaps/paste.xpm"
	#include "../bitmaps/print.xpm"
	#include "../bitmaps/find.xpm"
	#include "../bitmaps/Cursor_Shape.xpm"
	#include "../bitmaps/Add_Component.xpm"
	#include "../bitmaps/noconn.xpm"

	#include "../bitmaps/zoom.xpm"
	#include "../bitmaps/Zoom_Center.xpm"
	#include "../bitmaps/Zoom_Out.xpm"
	#include "../bitmaps/Zoom_In.xpm"
	#include "../bitmaps/Zoom_Optimal.xpm"
	#include "../bitmaps/Zoom_Select.xpm"
	#include "../bitmaps/Zoom_Selected.xpm"
	#include "../bitmaps/Repaint.xpm"

	#include "../bitmaps/left.xpm"
	#include "../bitmaps/right.xpm"
	#include "../bitmaps/up.xpm"
	#include "../bitmaps/down.xpm"

	#include "../bitmaps/File_FootPrint.xpm"

	#include "../bitmaps/Options_Pad.xpm"
	#include "../bitmaps/Options_New_Pad.xpm"

	#include "../bitmaps/sheetset.xpm"
	#include "../bitmaps/library.xpm"
	#include "../bitmaps/dashline.xpm"
	#include "../bitmaps/annotate.xpm"
	#include "../bitmaps/netlist.xpm"
	#include "../bitmaps/erc.xpm"
	#include "../bitmaps/tools.xpm"
	#include "../bitmaps/libview.xpm"
	#include "../bitmaps/libedprt.xpm"
	#include "../bitmaps/export.xpm"
	#include "../bitmaps/import.xpm"
	#include "../bitmaps/delete.xpm"
	#include "../bitmaps/schematic.xpm"
	#include "../bitmaps/pin.xpm"
	#include "../bitmaps/Morgan1.xpm"
	#include "../bitmaps/Morgan2.xpm"
	#include "../bitmaps/anchor.xpm"
	#include "../bitmaps/del_body.xpm"
	#include "../bitmaps/libsavem.xpm"
	#include "../bitmaps/label.xpm"
	#include "../bitmaps/undelete.xpm"
	#include "../bitmaps/undo.xpm"
	#include "../bitmaps/redo.xpm"
	#include "../bitmaps/eeschema.xpm"
	#include "../bitmaps/pcbnew.xpm"
	#include "../bitmaps/treensel.xpm"
	#include "../bitmaps/book.xpm"
	#include "../bitmaps/module.xpm"
	#include "../bitmaps/modedit.xpm"
	#include "../bitmaps/config.xpm"
	#include "../bitmaps/auto_associe.xpm"
	#include "../bitmaps/icon_cvpcb.xpm"
	#include "../bitmaps/icon_eeschema.xpm"
	#include "../bitmaps/icon_gerbview.xpm"
	#include "../bitmaps/icon_kicad.xpm"
	#include "../bitmaps/icon_pcbnew.xpm"
	#include "../bitmaps/icon_modedit.xpm"
	#include "../bitmaps/Info.xpm"
	#include "../bitmaps/mirepcb.xpm"
	#include "../bitmaps/icon_3d.xpm"
	#include "../bitmaps/drc_off.xpm"
	#include "../bitmaps/grid.xpm"
	#include "../bitmaps/grid_select.xpm"
	#include "../bitmaps/unit_mm.xpm"
	#include "../bitmaps/unit_inch.xpm"
	#include "../bitmaps/cursor.xpm"
	#include "../bitmaps/ratsnest.xpm"
	#include "../bitmaps/modratsnest.xpm"
	#include "../bitmaps/del_track.xpm"
	#include "../bitmaps/pad.xpm"
	#include "../bitmaps/Pad_Sketch.xpm"
	#include "../bitmaps/Text_Sketch.xpm"
	#include "../bitmaps/showtrack.xpm"
	#include "../bitmaps/showmodedge.xpm"
	#include "../bitmaps/showdcode.xpm"
	#include "../bitmaps/palette.xpm"
	#include "../bitmaps/help.xpm"
	#include "../bitmaps/green.xpm"
	#include "../bitmaps/red.xpm"
	#include "../bitmaps/preference.xpm"
	#include "../bitmaps/3d.xpm"
	#include "../bitmaps/hammer.xpm"
	#include "../bitmaps/jigsaw.xpm"
	#include "../bitmaps/library_update.xpm"
	#include "../bitmaps/transistor.xpm"
	#include "../bitmaps/kicad_icon_small.xpm"

// Largeur du toolbar vertical
#define VTOOLBAR_WIDTH 26
// dimension d'un tool vertical
#define TOOL_SIZE 23

==> kicad_0.0.20071129a.orig.tar.gz: kicad-0.0.20071129a.orig/include/bitmaps.h <==
	/****************************/
	/* Used bitmaps in Kicad */
	/****************************/

	#include "../bitmaps/Cancel.xpm"
	#include "../bitmaps/cancel_tool.xpm"
	#include "../bitmaps/Apply.xpm"
	#include "../bitmaps/Reload.xpm"

	#include "../bitmaps/icon_txt.xpm"
	#include "../bitmaps/new_txt.xpm"
	#include "../bitmaps/directory.xpm"
	#include "../bitmaps/icon_python_small.xpm"

	#include "../bitmaps/Fonts.xpm"

	#include "../bitmaps/save.xpm"
	#include "../bitmaps/save_as.xpm"
	#include "../bitmaps/Save_Project.xpm"
	#include "../bitmaps/Save_CmpStuff.xpm"
	#include "../bitmaps/Save_NetList.xpm"
	#include "../bitmaps/Save_SetUp.xpm"
	#include "../bitmaps/Read_SetUp.xpm"
	#include "../bitmaps/Editor.xpm"

	#include "../bitmaps/Open_Library.xpm"
	#include "../bitmaps/New_Library.xpm"
	#include "../bitmaps/Save_Library.xpm"

	#include "../bitmaps/Edit.xpm"
	#include "../bitmaps/Edit_Text.xpm"

	#include "../bitmaps/plot.xpm"
	#include "../bitmaps/plot_PS.xpm"
	#include "../bitmaps/plot_HPG.xpm"

	#include "../bitmaps/Add_Circle.xpm"
	#include "../bitmaps/Add_Line.xpm"
	#include "../bitmaps/Add_Arc.xpm"
	#include "../bitmaps/Add_Dashed_Line.xpm"
	#include "../bitmaps/Add_Entry.xpm"
	#include "../bitmaps/Add_Polygon.xpm"
	#include "../bitmaps/Add_Rectangle.xpm"
	#include "../bitmaps/Add_Text.xpm"
	#include "../bitmaps/Add_Line_Label.xpm"
	#include "../bitmaps/Add_GLabel.xpm"
	#include "../bitmaps/Add_Junction.xpm"

	#include "../bitmaps/general_deletions.xpm"
	#include "../bitmaps/Delete_Text.xpm"
	#include "../bitmaps/Delete_Cotation.xpm"
	#include "../bitmaps/Delete_Arc.xpm"
	#include "../bitmaps/Delete_Circle.xpm"
	#include "../bitmaps/Delete_Field.xpm"
	#include "../bitmaps/Delete_Line.xpm"
	#include "../bitmaps/Delete_Segment.xpm"
	#include "../bitmaps/Delete_Polygon.xpm"
	#include "../bitmaps/Delete_Rectangle.xpm"

	#include "../bitmaps/Move.xpm"
	#include "../bitmaps/Move_Text.xpm"
	#include "../bitmaps/Move_Arc.xpm"
	#include "../bitmaps/Move_Circle.xpm"
	#include "../bitmaps/Move_Field.xpm"
	#include "../bitmaps/Move_Line.xpm"
	#include "../bitmaps/Move_Polygon.xpm"
	#include "../bitmaps/Move_Rectangle.xpm"

	#include "../bitmaps/Options_Text.xpm"
	#include "../bitmaps/Options_Arc.xpm"
	#include "../bitmaps/Options_Circle.xpm"
	#include "../bitmaps/Options_Segment.xpm"
	#include "../bitmaps/Options_Rectangle.xpm"
	#include "../bitmaps/Display_Options.xpm"
	#include "../bitmaps/opt_show_polygon.xpm"

	#include "../bitmaps/Mirror_V.xpm"
	#include "../bitmaps/Mirror_H.xpm"
	#include "../bitmaps/Orient.xpm"
	#include "../bitmaps/Rotate+.xpm"
	#include "../bitmaps/Rotate-.xpm"
	#include "../bitmaps/Rotate_Field.xpm"
	#include "../bitmaps/Exit.xpm"
	#include "../bitmaps/Datasheet.xpm"
	#include "../bitmaps/CopyBlock.xpm"
	#include "../bitmaps/new.xpm"
	#include "../bitmaps/open.xpm"
	#include "../bitmaps/polar.xpm"
	#include "../bitmaps/copy.xpm"
	#include "../bitmaps/cut.xpm"
	#include "../bitmaps/paste.xpm"
	#include "../bitmaps/print.xpm"
	#include "../bitmaps/find.xpm"
	#include "../bitmaps/Cursor_Shape.xpm"
	#include "../bitmaps/Add_Component.xpm"
	#include "../bitmaps/noconn.xpm"

	#include "../bitmaps/zoom.xpm"
	#include "../bitmaps/Zoom_Center.xpm"
	#include "../bitmaps/Zoom_Out.xpm"
	#include "../bitmaps/Zoom_In.xpm"
	#include "../bitmaps/Zoom_Optimal.xpm"
	#include "../bitmaps/Zoom_Select.xpm"
	#include "../bitmaps/Zoom_Selected.xpm"
	#include "../bitmaps/Repaint.xpm"

	#include "../bitmaps/left.xpm"
	#include "../bitmaps/right.xpm"
	#include "../bitmaps/up.xpm"
	#include "../bitmaps/down.xpm"

	#include "../bitmaps/File_FootPrint.xpm"
	#include "../bitmaps/Footprint_Text.xpm"

	#include "../bitmaps/Options_Pad.xpm"
	#include "../bitmaps/Options_New_Pad.xpm"

	#include "../bitmaps/sheetset.xpm"
	#include "../bitmaps/library.xpm"
	#include "../bitmaps/dashline.xpm"
	#include "../bitmaps/annotate.xpm"
	#include "../bitmaps/netlist.xpm"
	#include "../bitmaps/erc.xpm"
	#include "../bitmaps/tools.xpm"
	#include "../bitmaps/libview.xpm"
	#include "../bitmaps/libedprt.xpm"
	#include "../bitmaps/export.xpm"
	#include "../bitmaps/import.xpm"
	#include "../bitmaps/delete.xpm"
	#include "../bitmaps/schematic.xpm"
	#include "../bitmaps/pin.xpm"
	#include "../bitmaps/Morgan1.xpm"
	#include "../bitmaps/Morgan2.xpm"
	#include "../bitmaps/anchor.xpm"
	#include "../bitmaps/del_body.xpm"
	#include "../bitmaps/libsavem.xpm"
	#include "../bitmaps/label.xpm"
	#include "../bitmaps/undelete.xpm"
	#include "../bitmaps/undo.xpm"
	#include "../bitmaps/redo.xpm"
	#include "../bitmaps/eeschema.xpm"
	#include "../bitmaps/pcbnew.xpm"
	#include "../bitmaps/treensel.xpm"
	#include "../bitmaps/book.xpm"
	#include "../bitmaps/module.xpm"
	#include "../bitmaps/modedit.xpm"
	#include "../bitmaps/config.xpm"
	#include "../bitmaps/auto_associe.xpm"
	#include "../bitmaps/icon_cvpcb.xpm"
	#include "../bitmaps/icon_eeschema.xpm"
	#include "../bitmaps/icon_gerbview.xpm"
	#include "../bitmaps/icon_kicad.xpm"
	#include "../bitmaps/icon_pcbnew.xpm"
	#include "../bitmaps/icon_modedit.xpm"
	#include "../bitmaps/Info.xpm"
	#include "../bitmaps/icon_python.xpm"
	#include "../bitmaps/mirepcb.xpm"
	#include "../bitmaps/icon_3d.xpm"
	#include "../bitmaps/drc_off.xpm"
	#include "../bitmaps/grid.xpm"
	#include "../bitmaps/grid_select.xpm"
	#include "../bitmaps/unit_mm.xpm"
	#include "../bitmaps/unit_inch.xpm"
	#include "../bitmaps/cursor.xpm"
	#include "../bitmaps/ratsnest.xpm"
	#include "../bitmaps/modratsnest.xpm"
	#include "../bitmaps/del_track.xpm"
	#include "../bitmaps/pad.xpm"
	#include "../bitmaps/Pad_Sketch.xpm"
	#include "../bitmaps/Text_Sketch.xpm"
	#include "../bitmaps/showtrack.xpm"
	#include "../bitmaps/showmodedge.xpm"
	#include "../bitmaps/showdcode.xpm"
	#include "../bitmaps/palette.xpm"
	#include "../bitmaps/help.xpm"
	#include "../bitmaps/green.xpm"
	#include "../bitmaps/red.xpm"
	#include "../bitmaps/preference.xpm"
	#include "../bitmaps/3d.xpm"
	#include "../bitmaps/hammer.xpm"
	#include "../bitmaps/jigsaw.xpm"
	#include "../bitmaps/library_update.xpm"
	#include "../bitmaps/transistor.xpm"
	#include "../bitmaps/kicad_icon_small.xpm"
	#include "../bitmaps/general_ratsnet.xpm"
	#include "../bitmaps/fill_zone.xpm"

// Largeur du toolbar vertical
#define VTOOLBAR_WIDTH 26
// dimension d'un tool vertical
#define TOOL_SIZE 23
